{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Initial CNVkit analysis",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/anti_targets"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#main/bams"
                },
                {
                    "type": "File",
                    "id": "#main/reference_coverage"
                },
                {
                    "type": "File",
                    "id": "#main/targets"
                }
            ],
            "steps": [
                {
                    "run": "#cnvkit_coverage.cwl",
                    "scatter": [
                        "#main/antitarget_sample_coverage/bam"
                    ],
                    "in": [
                        {
                            "source": "#main/bams",
                            "id": "#main/antitarget_sample_coverage/bam"
                        },
                        {
                            "source": "#main/anti_targets",
                            "id": "#main/antitarget_sample_coverage/bed"
                        },
                        {
                            "default": false,
                            "id": "#main/antitarget_sample_coverage/istarget"
                        }
                    ],
                    "out": [
                        "#main/antitarget_sample_coverage/coverage"
                    ],
                    "id": "#main/antitarget_sample_coverage"
                },
                {
                    "run": "#cnvkit_segment.cwl",
                    "scatter": [
                        "#main/cna_segments/coverage"
                    ],
                    "in": [
                        {
                            "source": "#main/fix_coverage/ratios",
                            "id": "#main/cna_segments/coverage"
                        }
                    ],
                    "out": [
                        "#main/cna_segments/cna_segmented"
                    ],
                    "id": "#main/cna_segments"
                },
                {
                    "run": "#cnvkit_fix.cwl",
                    "scatter": [
                        "#main/fix_coverage/target_coverage",
                        "#main/fix_coverage/antitarget_coverage"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/antitarget_sample_coverage/coverage",
                            "id": "#main/fix_coverage/antitarget_coverage"
                        },
                        {
                            "source": "#main/reference_coverage",
                            "id": "#main/fix_coverage/reference_coverage"
                        },
                        {
                            "source": "#main/target_sample_coverage/coverage",
                            "id": "#main/fix_coverage/target_coverage"
                        }
                    ],
                    "out": [
                        "#main/fix_coverage/ratios"
                    ],
                    "id": "#main/fix_coverage"
                },
                {
                    "run": "#cnvkit_coverage.cwl",
                    "scatter": [
                        "#main/target_sample_coverage/bam"
                    ],
                    "in": [
                        {
                            "source": "#main/bams",
                            "id": "#main/target_sample_coverage/bam"
                        },
                        {
                            "source": "#main/targets",
                            "id": "#main/target_sample_coverage/bed"
                        },
                        {
                            "default": true,
                            "id": "#main/target_sample_coverage/istarget"
                        }
                    ],
                    "out": [
                        "#main/target_sample_coverage/coverage"
                    ],
                    "id": "#main/target_sample_coverage"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/antitarget_sample_coverage/coverage",
                    "id": "#main/antitarget_coverage"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/fix_coverage/ratios",
                    "id": "#main/fixed_cnr"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/cna_segments/cna_segmented",
                    "id": "#main/segmented"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/target_sample_coverage/coverage",
                    "id": "#main/target_coverage"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "CNVkit coverage",
            "baseCommand": [
                "cnvkit.py",
                "coverage"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 4,
                    "ramMin": 64000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "jbwebster/cna_pipeline_docker"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cnvkit_coverage.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#cnvkit_coverage.cwl/bed"
                },
                {
                    "type": "boolean",
                    "id": "#cnvkit_coverage.cwl/istarget"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "${\n  var x = String(inputs.bam.nameroot)\n  var suffix = \"\";\n  if (inputs.istarget) {\n    suffix = \".targetcoverage.cnn\";\n  } else {\n    suffix = \".antitargetcoverage.cnn\";\n  }\n  var xx = x + suffix;\n  return xx;\n}\n",
                    "position": 3,
                    "prefix": "-o"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*coverage.cnn"
                    },
                    "id": "#cnvkit_coverage.cwl/coverage"
                }
            ],
            "id": "#cnvkit_coverage.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "CNVkit fix",
            "baseCommand": [
                "cnvkit.py",
                "fix"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "jbwebster/cna_pipeline_docker"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 4,
                    "ramMin": 15000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#cnvkit_fix.cwl/antitarget_coverage"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#cnvkit_fix.cwl/reference_coverage"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#cnvkit_fix.cwl/target_coverage"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "--no-edge",
                    "position": 1
                },
                {
                    "valueFrom": "${ var x = String(inputs.target_coverage.nameroot).split('.')[0]; var xx = x + \".cnr\" ; return xx; }",
                    "position": 5,
                    "prefix": "-o"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.cnr"
                    },
                    "id": "#cnvkit_fix.cwl/ratios"
                }
            ],
            "id": "#cnvkit_fix.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "CNVkit segment",
            "baseCommand": [
                "cnvkit.py",
                "segment"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 4,
                    "ramMin": 64000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "jbwebster/cna_pipeline_docker"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cnvkit_segment.cwl/coverage"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "${\n  var x = String(inputs.coverage.basename).split('.')[0];\n  var xx = x + \".cns\";\n  return xx;\n}\n",
                    "position": 2,
                    "prefix": "-o"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.cns"
                    },
                    "id": "#cnvkit_segment.cwl/cna_segmented"
                }
            ],
            "id": "#cnvkit_segment.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
